==> mod-ui-1.1.47.tgz: package/tailwind.config.js <==
/** @type {import('tailwindcss').Config} */
module.exports = {
  content: [
    "./src/**/*.{html,ts,js,scss}",
  ],
  theme: {
    extend: {
      colors: {
        'primary': 'var(--primary)',
        'secondary': 'var(--secondary)',

        'opacity-bg': 'var(--opacity-bg)',
        'border-bg': 'var(--border-bg)',
        'scrollbar-bg': 'var(--scrollbar-bg)',
        'body-bg': 'var(--body-bg)',
        'disabled-bg': 'var(--disabled-bg)',
        'hover-bg': 'var(--hover-bg)',
        'dropdown-bg': 'var(--dropdown-bg)',
        'table-h-bg': 'var(--table-h-bg)',
        'input-bg': 'var(--input-bg)',

        'body-text': 'var(--body-text)',
        'title-text': 'var(--title-text)',
        'caption-text': 'var(--caption-text)',
        'input-text': 'var(--input-text)',
        'placeholder-text': 'var(--placeholder-text)',
        'info-text': 'var(--info-text)',

        'success': 'var(--success)',
        'warning': 'var(--warning)',
        'error': 'var(--error)',

        'black': 'var(--black)',
        'white': 'var(--white)',

        'facebook': 'var(--facebook)',
        'instagram':  'var(--instagram)',
        'line': 'var(--line)',
        'shopee': 'var(--shopee)',
        'lazada': 'var(--lazada)',
        'website':  'var(--website)',
        'other':  'var(--other)',
        'twitter':  'var(--twitter)',
        'tiktok': 'var(--tiktok)',

        'black-1': 'var(--black-1)',
        'black-2': 'var(--black-2)',
        'black-3': 'var(--black-3)',
        'black-4': 'var(--black-4)',
        'black-5': 'var(--black-5)',
        'black-6': 'var(--black-6)',
        'black-7': 'var(--black-7)',
        'black-8': 'var(--black-8)',
        'black-9': 'var(--black-9)',

        'purple-0': 'var(--purple-0)',
        'purple-1': 'var(--purple-1)',
        'purple-2': 'var(--purple-2)',
        'purple-3': 'var(--purple-3)',
        'purple-4': 'var(--purple-4)',
        'purple-5': 'var(--purple-5)',
        'purple-6': 'var(--purple-6)',
        'purple-7': 'var(--purple-7)',
        'purple-8': 'var(--purple-8)',

        'blue-1': 	'var(--blue-1)',
        'blue-2': 	'var(--blue-2)',
        'blue-3': 	'var(--blue-3)',
        'blue-4': 	'var(--blue-4)',
        'blue-5': 	'var(--blue-5)',
        'blue-6': 	'var(--blue-6)',
        'blue-7': 	'var(--blue-7)',
        'blue-8': 	'var(--blue-8)',
        'blue-9': 	'var(--blue-9)',

        'green-1': 'var(--green-1)',
        'green-2': 'var(--green-2)',
        'green-3': 'var(--green-3)',
        'green-4': 'var(--green-4)',
        'green-5': 'var(--green-5)',
        'green-6': 'var(--green-6)',
        'green-7': 'var(--green-7)',

        'red-1': 	'var(--red-1)',
        'red-2': 	'var(--red-2)',
        'red-3': 	'var(--red-3)',
        'red-4': 	'var(--red-4)',
        'red-5': 	'var(--red-5)',
        'red-6': 	'var(--red-6)',
        'red-7': 	'var(--red-7)',

        'orange-1': 'var(--orange-1)',
        'orange-2': 'var(--orange-2)',
        'orange-3': 'var(--orange-3)',
        'orange-4': 'var(--orange-4)',
        'orange-5': 'var(--orange-5)',
        'orange-6': 'var(--orange-6)',
        'orange-7': 'var(--orange-7)',
        'orange-8': 'var(--orange-8)',
        'orange-9': 'var(--orange-9)',

        'yellow-1': 'var(--yellow-1)',
        'yellow-2': 'var(--yellow-2)',
        'yellow-3': 'var(--yellow-3)',
        'yellow-4': 'var(--yellow-4)',
        'yellow-5': 'var(--yellow-5)',
        'yellow-6': 'var(--yellow-6)',
        'yellow-7': 'var(--yellow-7)',

        'magenta-1': 'var(--magenta-1)',
        'magenta-2': 'var(--magenta-2)',
        'magenta-3': 'var(--magenta-3)',
        'magenta-4': 'var(--magenta-4)',
        'magenta-5': 'var(--magenta-5)',
        'magenta-6': 'var(--magenta-6)',
        'magenta-7': 'var(--magenta-7)',
      },
      fontFamily: {
        'primary': 'var(--primary-font)',
        'thonburi': 'var(--thonburi-font)',
        'sarabun': 'var(--sarabun-font)',
      },
      zIndex: {
        '1': '1',
      },
      width: {
        '960': '960px'
      },
      minWidth: {
        '1200': '1200px'
      },
      maxWidth: {
        '480': '480px'
      },
      height: {
        '120': '120px'
      },
      minHeight: {
        '400': '400px',
      },
      maxHeight: {
        '245': '245px',
        '315': '315px',
        '540': '540px'
      },
      boxShadow: {
        'xs': '16px 0 4px rgba(0,0,0,0.1)',
        'card': 'var(--shadow-3)',
        'card-hover': 'var(--shadow-4)',
        'checkbox-hover': 'var(--shadow-5)',
        'button-hover': 'var(--shadow-1)',
        'focus-hover': 'var(--shadow-2)',
      },
      screens: {
        '1440': '1440px',
        '1920': '1920px',
      },
    },
  },
  variants: {
    extend: {},
  },
  plugins: [],
}

==> mod-ui-1.1.75.tgz: package/tailwind.config.js <==
/** @type {import('tailwindcss').Config} */
module.exports = {
  content: [
    "./src/**/*.{html,ts,js,scss}",
  ],
  theme: {
    extend: {
      colors: {
        'primary': 'var(--primary)',
        'secondary': 'var(--secondary)',
        'my-ai': 'var(--my-ai)',
        'pinmall': 'var(--pinmall)',

        'opacity-bg': 'var(--opacity-bg)',
        'border-bg': 'var(--border-bg)',
        'scrollbar-bg': 'var(--scrollbar-bg)',
        'body-bg': 'var(--body-bg)',
        'body-2025-bg': 'var(--body-2025-bg)',
        'disabled-bg': 'var(--disabled-bg)',
        'hover-bg': 'var(--hover-bg)',
        'dropdown-bg': 'var(--dropdown-bg)',
        'table-h-bg': 'var(--table-h-bg)',
        'input-bg': 'var(--input-bg)',
        'content1-bg': 'var(--content1-bg)',
        'content2-bg': 'var(--content2-bg)',
        'ai-pastel-bg': 'var(--ai-pastel-bg)',
        'ai-pastel2-bg': 'var(--ai-pastel2-bg)',
        'ai-off-white-bg': 'var(--ai-off-white-bg)',

        'body-text': 'var(--body-text)',
        'title-text': 'var(--title-text)',
        'caption-text': 'var(--caption-text)',
        'input-text': 'var(--input-text)',
        'placeholder-text': 'var(--placeholder-text)',
        'info-text': 'var(--info-text)',

        'success': 'var(--success)',
        'warning': 'var(--warning)',
        'error': 'var(--error)',

        'black': 'var(--black)',
        'white': 'var(--white)',

        'facebook': 'var(--facebook)',
        'instagram':  'var(--instagram)',
        'line': 'var(--line)',
        'shopee': 'var(--shopee)',
        'lazada': 'var(--lazada)',
        'website':  'var(--website)',
        'other':  'var(--other)',
        'twitter':  'var(--twitter)',
        'tiktok': 'var(--tiktok)',

        'black-1': 'var(--black-1)',
        'black-2': 'var(--black-2)',
        'black-3': 'var(--black-3)',
        'black-4': 'var(--black-4)',
        'black-5': 'var(--black-5)',
        'black-6': 'var(--black-6)',
        'black-7': 'var(--black-7)',
        'black-8': 'var(--black-8)',
        'black-9': 'var(--black-9)',

        'purple-0': 'var(--purple-0)',
        'purple-1': 'var(--purple-1)',
        'purple-2': 'var(--purple-2)',
        'purple-3': 'var(--purple-3)',
        'purple-4': 'var(--purple-4)',
        'purple-5': 'var(--purple-5)',
        'purple-6': 'var(--purple-6)',
        'purple-7': 'var(--purple-7)',
        'purple-8': 'var(--purple-8)',

        'blue-1': 	'var(--blue-1)',
        'blue-2': 	'var(--blue-2)',
        'blue-3': 	'var(--blue-3)',
        'blue-4': 	'var(--blue-4)',
        'blue-5': 	'var(--blue-5)',
        'blue-6': 	'var(--blue-6)',
        'blue-7': 	'var(--blue-7)',
        'blue-8': 	'var(--blue-8)',
        'blue-9': 	'var(--blue-9)',

        'green-1': 'var(--green-1)',
        'green-2': 'var(--green-2)',
        'green-3': 'var(--green-3)',
        'green-4': 'var(--green-4)',
        'green-5': 'var(--green-5)',
        'green-6': 'var(--green-6)',
        'green-7': 'var(--green-7)',

        'red-1': 	'var(--red-1)',
        'red-2': 	'var(--red-2)',
        'red-3': 	'var(--red-3)',
        'red-4': 	'var(--red-4)',
        'red-5': 	'var(--red-5)',
        'red-6': 	'var(--red-6)',
        'red-7': 	'var(--red-7)',

        'orange-1': 'var(--orange-1)',
        'orange-2': 'var(--orange-2)',
        'orange-3': 'var(--orange-3)',
        'orange-4': 'var(--orange-4)',
        'orange-5': 'var(--orange-5)',
        'orange-6': 'var(--orange-6)',
        'orange-7': 'var(--orange-7)',
        'orange-8': 'var(--orange-8)',
        'orange-9': 'var(--orange-9)',

        'yellow-1': 'var(--yellow-1)',
        'yellow-2': 'var(--yellow-2)',
        'yellow-3': 'var(--yellow-3)',
        'yellow-4': 'var(--yellow-4)',
        'yellow-5': 'var(--yellow-5)',
        'yellow-6': 'var(--yellow-6)',
        'yellow-7': 'var(--yellow-7)',

        'magenta-1': 'var(--magenta-1)',
        'magenta-2': 'var(--magenta-2)',
        'magenta-3': 'var(--magenta-3)',
        'magenta-4': 'var(--magenta-4)',
        'magenta-5': 'var(--magenta-5)',
        'magenta-6': 'var(--magenta-6)',
        'magenta-7': 'var(--magenta-7)',
      },
      fontFamily: {
        'primary': 'var(--primary-font)',
        'thonburi': 'var(--thonburi-font)',
        'sarabun': 'var(--sarabun-font)',
      },
      zIndex: {
        '1': '1',
      },
      width: {
        '960': '960px'
      },
      minWidth: {
        '1200': '1200px'
      },
      maxWidth: {
        '480': '480px'
      },
      height: {
        '120': '120px'
      },
      minHeight: {
        '400': '400px',
      },
      maxHeight: {
        '245': '245px',
        '315': '315px',
        '540': '540px'
      },
      boxShadow: {
        'xs': '16px 0 4px rgba(0,0,0,0.1)',
        'button-hover': 'var(--button-hover-shadow)',
        'focus-hover': 'var(--focus-hover-shadow)',
        'dropdown': 'var(--dropdown-shadow)',
        'modal': 'var(--modal-shadow)',
        'card': 'var(--card-shadow)',
        'card-hover': 'var(--card-hover-shadow)',
        'checkbox-hover': 'var(--checkbox-hover-shadow)',
      },
      screens: {
        '1440': '1440px',
        '1920': '1920px',
      },
      fontSize: {
        13: '13px',
      },
    },
  },
  variants: {
    extend: {},
  },
  plugins: [],
}
